@@ -1,12 +1,13 @@
 package PAR::StrippedPARL::Base;
-use 5.006;
+use 5.008001;
 use strict;
 use warnings;
 our $VERSION = '0.975';
 
 use File::Temp ();
 use File::Spec;
-use Config ();
+use Cwd;
+use Config;
 
 =head1 NAME
 
@@ -48,41 +49,34 @@ sub write_parl {
     my $file = shift;
     if (not defined $file) {
         warn "${class}->write_parl() needs a file name as argument";
-        return();
+        return;
     }
 
     # write out to a temporary file first
     my ($fh, $tfile) = File::Temp::tempfile(
-        "parlXXXX", SUFFIX => $Config::Config{_exe}||'', TMPDIR => 1);
+        "parlXXXX", SUFFIX => $Config{_exe}||'', TMPDIR => 1, UNLINK => 1);
     close $fh;
-    # File::Temp, you suck!
 
     if (not $class->write_raw($tfile)) {
         unlink($tfile);
         warn "Could not write temporary parl (class $class) to file '$tfile'";
-        return();
+        return;
     }
-    chmod(oct('755'), $tfile);
+    chmod(0755, $tfile);
 
     # Use this to generate a real parl
     my @libs = ();
     for my $ilib ( @INC ) {
+        next if ref $ilib;
         $ilib =~ s/\\$/\\\\/;
         push(@libs, qq(-I$ilib) );
     }
-    my @args = (@libs, qw/-q -B/);
-
-    # prepend ./ if applicable
-    my $execute = $tfile;
-    my @dirs = File::Spec->splitdir(
-        (File::Spec->splitpath($execute))[1] # directory part only
-    );
-    $execute = File::Spec->catfile(File::Spec->curdir(), $tfile) if not @dirs;
-    system($execute, @args, "-O$file") and unlink($tfile), return();
-    
-    # clean up
-    unlink($tfile);
 
+    system(Cwd::abs_path($tfile), @libs, qw( -q -B ), "-O$file");
+    unless ($? == 0) {
+        warn "Failed to execute temporary parl (class $class) in file '$tfile': $!";
+        return;
+    }
     return 1;
 }
 
@@ -96,7 +90,7 @@ Returns the empty list on failure.
 
 sub get_raw {
     my $class = shift;
-    my $pos = $class->_data_pos(); 
+    my $pos = $class->_data_pos();
     if (not defined $pos) {
         warn "${class}->_data_pos() did not return the original tell() position of the DATA file handle";
         return();
@@ -161,10 +155,10 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.
 
-This program is free software; you can redistribute it and/or 
+This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See L<http://www.perl.com/perl/misc/Artistic.html>
+See F<LICENSE>.
 
 =cut
 
