@@ -1,4 +1,5 @@
 #include "mktmpdir.h"
+#include "sha1.h"
 
 #define PAR_TEMP "PAR_TEMP"
 
@@ -50,8 +51,7 @@ static int isSafeDir(const char* val)
 
 void par_setup_libpath( const char * stmpdir )
 {
-    const char *key = NULL , *val = NULL;
-    int i;
+    const char *val = NULL;
     char *ld_path = LDLIBPTHNAME;
     char *ld_path_env = NULL;
 
@@ -92,7 +92,7 @@ char *par_mktmpdir ( char **argv ) {
     char *stmpdir = NULL, *top_tmpdir = NULL;
     int f, j, k, stmp_len = 0;
     char sha1[41];
-    SHA_INFO sha_info;
+    SHA_INFO *sha_info;
     unsigned char buf[32768];
     unsigned char sha_data[20];
 
@@ -194,7 +194,7 @@ char *par_mktmpdir ( char **argv ) {
     /* Doesn't really work - XXX */
     val = par_getenv( "PATH" );
     if (val != NULL)
-        progname = par_findprog(argv[0], strdup(val));
+        progname = par_findprog(argv[0], val);
     if (progname == NULL)
         progname = argv[0];
 
@@ -238,13 +238,13 @@ char *par_mktmpdir ( char **argv ) {
         else {
             /* "$TEMP/par-$USER/cache-$SHA1" */
 	    lseek(f, 0, 0);
-            sha_init( &sha_info );
+            sha_info = sha_init();
             while( ( j = read( f, buf, sizeof( buf ) ) ) > 0 )
             {
-                sha_update( &sha_info, buf, j );
+                sha_update( sha_info, buf, j );
             }
             close( f );
-            sha_final( sha_data, &sha_info );
+            sha_final( sha_data, sha_info );
             for( k = 0; k < 20; k++ )
             {
                 sprintf( sha1+k*2, "%02x", sha_data[k] );
