@@ -20,6 +20,8 @@ sub pp_ok
     my $exe = catfile($ENV{PAR_TMPDIR},"packed$Config{_exe}");
     unlink($exe);
 
+    die "system(LIST) with double quotes in LIST doesn't work on Windows: @_"
+        if grep { /"/ } @_;
     system($^X, $pp, -o => $exe, @_);
     # Note: -x is unreliable on Windows
     ok( $? == 0 && -f $exe, qq[successfully packed "$exe"] );
@@ -34,7 +36,7 @@ sub run_ok
 
     my ($out, $err);
     run3(\@cmd, \undef, \$out, \$err);
-    ok( $? == 0, qq[successfully ran "@cmd"] );
+    is( $?, 0, qq[successfully ran "@cmd"] );
 
     return ($out, $err);
 }
